@@ -8,11 +8,12 @@ use nix::sys::stat::SFlag;
 use regex::*;
 use std::cell::RefCell;
 use std::collections::HashMap;
+use std::convert::TryInto;
 use std::fmt;
 use std::io::BufRead;
 use std::net::Ipv4Addr;
 use std::net::Ipv6Addr;
-use std::os::unix::io::RawFd;
+use std::os::fd::BorrowedFd;
 use std::str::FromStr;
 
 #[derive(Debug, PartialEq, PartialOrd, Hash, Eq, Clone)]
@@ -38,6 +39,7 @@ pub struct Config {
     pub used: Option<HashMap<Ip, bool>>,
     pub input_family: Option<InputFamily>,
     pub net_used: HashMap<Ip, HashMap<Ip, bool>>,
+    pub options: HashMap<String, String>,
 }
 
 #[derive(Debug, Clone)]
@@ -70,14 +72,40 @@ pub enum Reverse {
     Both,
 }
 
+pub enum MaskType {
+    Network,
+    Broadcast,
+    Wildcard,
+    SubnetMask,
+}
+
+impl Config {
+    pub fn new() -> Config {
+        Config {
+            interface_names: vec![],
+            hm: HashMap::new(),
+            used: None,
+            input_family: None,
+            net_used: HashMap::new(),
+            options: HashMap::new(),
+        }
+    }
+}
+
+impl Default for Config {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 impl Ip {
-    fn num_representation(&self) -> String {
+    pub fn num_representation(&self) -> String {
         match self.address {
             Addr::V4(x) => u32::from(x).to_string(),
             Addr::V6(x) => u128::from(x).to_string(),
         }
     }
-    fn signed_num_representation(&self) -> String {
+    pub fn signed_num_representation(&self) -> String {
         match self.address {
             Addr::V4(x) => {
                 let n = u32::from(x) as i32;
@@ -89,13 +117,13 @@ impl Ip {
             }
         }
     }
-    fn bin_representation(&self) -> String {
+    pub fn bin_representation(&self) -> String {
         match self.address {
             Addr::V4(x) => format!("{:032b}", u32::from(x)),
             Addr::V6(x) => format!("{:0128b}", u128::from(x)),
         }
     }
-    fn bin_split_representation(&self) -> String {
+    pub fn bin_split_representation(&self) -> String {
         let mut s = match self.address {
             Addr::V4(x) => format!("{:032b}", u32::from(x)),
             Addr::V6(x) => format!("{:0128b}", u128::from(x)),
@@ -103,7 +131,7 @@ impl Ip {
         s.insert(self.cidr as usize, ' ');
         s
     }
-    fn hex_quad_representation(&self) -> String {
+    pub fn hex_quad_representation(&self) -> String {
         match self.address {
             Addr::V4(x) => {
                 let mut s: String = "".to_string();
@@ -340,6 +368,55 @@ pub fn parse_address_mask(
     None
 }
 
+pub fn network_iter(ip: &Ip) -> impl std::iter::Iterator<Item = Ip> + '_ {
+    mask_iter(ip, &MaskType::Network)
+}
+
+pub fn broadcast_iter(ip: &Ip) -> impl std::iter::Iterator<Item = Ip> + '_ {
+    mask_iter(ip, &MaskType::Broadcast)
+}
+
+pub fn wildcard_iter(ip: &Ip) -> impl std::iter::Iterator<Item = Ip> + '_ {
+    mask_iter(ip, &MaskType::Wildcard)
+}
+
+pub fn subnet_iter(ip: &Ip) -> impl std::iter::Iterator<Item = Ip> + '_ {
+    mask_iter(ip, &MaskType::SubnetMask)
+}
+
+pub fn mask_iter<'a>(
+    ip: &'a Ip,
+    mask_type: &'a MaskType,
+) -> impl std::iter::Iterator<Item = Ip> + 'a {
+    let mut cidr: i32 = ip.cidr.try_into().unwrap();
+
+    std::iter::from_fn(move || {
+        if cidr == -1 {
+            None
+        } else {
+            cidr -= 1;
+            Some(match mask_type {
+                MaskType::Network => network(&Ip {
+                    address: ip.address.clone(),
+                    cidr: (cidr + 1) as u32,
+                }),
+                MaskType::Broadcast => broadcast(&Ip {
+                    address: ip.address.clone(),
+                    cidr: (cidr + 1) as u32,
+                }),
+                MaskType::SubnetMask => subnet(&Ip {
+                    address: ip.address.clone(),
+                    cidr: (cidr + 1) as u32,
+                }),
+                MaskType::Wildcard => wildcard(&Ip {
+                    address: ip.address.clone(),
+                    cidr: (cidr + 1) as u32,
+                }),
+            })
+        }
+    })
+}
+
 pub fn addresses<'a>(
     ip: &'a Ip,
     used: Option<&'a HashMap<Addr, bool>>,
@@ -628,6 +705,31 @@ pub fn subnet(ip: &Ip) -> Ip {
     }
 }
 
+pub fn wildcard(ip: &Ip) -> Ip {
+    match ip.address {
+        Addr::V4(_x) => {
+            let mut bin: u32 = 0;
+            for i in 0..32 - ip.cidr {
+                bin |= 1 << i;
+            }
+            Ip {
+                address: Addr::V4(Ipv4Addr::from(bin)),
+                cidr: ip.cidr,
+            }
+        }
+        Addr::V6(_x) => {
+            let mut bin: u128 = 0;
+            for i in 0..128 - ip.cidr {
+                bin |= 1 << i;
+            }
+            Ip {
+                address: Addr::V6(Ipv6Addr::from(bin)),
+                cidr: ip.cidr,
+            }
+        }
+    }
+}
+
 // if addr's network is lower, or addr's broadcast is higher, then not within outside
 pub fn within(net: &Ip, addr: &Ip) -> bool {
     match (&net.address, &addr.address) {
@@ -946,69 +1048,17 @@ pub fn network_reservation(ip: &Ip) -> Option<String> {
         "Link local".to_string(),
     );
 
-    match ip.address {
-        Addr::V4(x) => {
-            let search_ip = x;
+    for i in network_iter(&ip.clone()) {
+        let net_row = rows.get(&network(&i));
 
-            for i in 0..32 {
-                let cidr = 32 - i;
-
-                let net_row = rows.get(&network(&Ip {
-                    address: Addr::V4(search_ip),
-                    cidr,
-                }));
-
-                if let Some(s) = net_row {
-                    return Some(s.to_string());
-                }
-            }
-        }
-        Addr::V6(x) => {
-            let search_ip = x;
-
-            for i in 0..128 {
-                let cidr = 128 - i;
-
-                let net_row = rows.get(&network(&Ip {
-                    address: Addr::V6(search_ip),
-                    cidr,
-                }));
-
-                if let Some(s) = net_row {
-                    return Some(s.to_string());
-                }
-            }
+        if let Some(s) = net_row {
+            return Some(s.to_string());
         }
     }
 
     None
 }
 
-pub fn wildcard(ip: &Ip) -> Ip {
-    match ip.address {
-        Addr::V4(_x) => {
-            let mut bin: u32 = 0;
-            for i in 0..32 - ip.cidr {
-                bin |= 1 << i;
-            }
-            Ip {
-                address: Addr::V4(Ipv4Addr::from(bin)),
-                cidr: ip.cidr,
-            }
-        }
-        Addr::V6(_x) => {
-            let mut bin: u128 = 0;
-            for i in 0..128 - ip.cidr {
-                bin |= 1 << i;
-            }
-            Ip {
-                address: Addr::V6(Ipv6Addr::from(bin)),
-                cidr: ip.cidr,
-            }
-        }
-    }
-}
-
 pub fn matching_network_interface(
     ip: &Ip,
     interfaces: &[InterfaceAddress],
@@ -1182,70 +1232,27 @@ pub fn format_details(
 
         let rows = rows.as_ref().unwrap();
 
-        match ip.address {
-            Addr::V4(x) => {
-                let search_ip = x;
+        for i in network_iter(&Ip {
+            address: ip.address.clone(),
+            cidr: ip.cidr,
+        }) {
+            let net_row = rows.get(&i);
 
-                for i in 0..32 {
-                    let cidr = 32 - i;
-                    let mn = network(&Ip {
-                        address: Addr::V4(search_ip),
-                        cidr,
-                    });
-
-                    let net_row = rows.get(&Ip {
-                        address: mn.address,
-                        cidr,
-                    });
-
-                    if net_row.is_none() {
-                        continue;
-                    }
-
-                    let net_row = net_row.unwrap();
-                    ip.cidr = cidr;
-
-                    for f in net_row.row.keys() {
-                        reformatted = reformatted
-                            .replace(&format!("%{{{}}}", f), net_row.row.get(f).unwrap());
-                    }
-                    found_match = true;
-
-                    break;
-                }
+            if net_row.is_none() {
+                continue;
             }
-            Addr::V6(x) => {
-                let search_ip = x;
 
-                for i in 0..128 {
-                    let cidr = 128 - i;
-                    let mn = network(&Ip {
-                        address: Addr::V6(search_ip),
-                        cidr,
-                    });
+            let net_row = net_row.unwrap();
 
-                    let net_row = rows.get(&Ip {
-                        address: mn.address,
-                        cidr,
-                    });
-
-                    if net_row.is_none() {
-                        continue;
-                    }
-
-                    ip.cidr = cidr;
-
-                    let net_row = net_row.unwrap();
-
-                    for f in net_row.row.keys() {
-                        reformatted = reformatted
-                            .replace(&format!("%{{{}}}", f), net_row.row.get(f).unwrap());
-                    }
-                    found_match = true;
-
-                    break;
-                }
+            for f in net_row.row.keys() {
+                reformatted =
+                    reformatted.replace(&format!("%{{{}}}", f), net_row.row.get(f).unwrap());
             }
+
+            ip.cidr = i.cidr;
+            found_match = true;
+
+            break;
         }
         if !found_match {
             if let Some(m) = matches {
@@ -1415,7 +1422,7 @@ pub fn format_details(
     Some(out_str)
 }
 
-pub fn fd_ready(fd: RawFd) -> bool {
+pub fn fd_ready(fd: BorrowedFd) -> bool {
     let s = fstat(fd);
     if let Ok(x) = s {
         if SFlag::S_IFIFO.bits() & x.st_mode == SFlag::S_IFIFO.bits() {
@@ -1453,7 +1460,15 @@ pub fn find_ips<'a>(
                 ) {
                     Some(x) => x,
                     None => {
-                        eprintln!("Could not parse {}", p);
+                        if config
+                            .borrow()
+                            .options
+                            .get("quiet")
+                            .unwrap_or(&"false".to_string())
+                            != "true"
+                        {
+                            eprintln!("Could not parse {}", p);
+                        }
                         continue;
                     }
                 };
