@@ -4,7 +4,7 @@ use std::cell::RefCell;
 use std::collections::HashMap;
 use std::fs::File;
 use std::io::{BufRead, BufReader};
-use std::os::unix::io::AsRawFd;
+use std::os::fd::AsFd;
 use std::str::FromStr;
 
 fn print_details(
@@ -420,13 +420,7 @@ fn main() {
     let mut inside: Option<bool> = None;
     let args: Vec<String> = std::env::args().collect();
     let mut ip_args: Vec<Ip> = vec![];
-    let config = RefCell::new(Config {
-        interface_names: vec![],
-        hm: HashMap::new(),
-        used: None,
-        input_family: None,
-        net_used: HashMap::new(),
-    });
+    let config = RefCell::new(Config::new());
 
     opts.parsing_style(getopts::ParsingStyle::FloatingFrees);
     opts.optflag("4", "ipv4", "treat inputs as ipv4 address");
@@ -474,6 +468,8 @@ fn main() {
         "CIDR",
     );
 
+    opts.optflag("q", "quiet", "don't report errors");
+
     opts.optopt(
         "r",
         "reverse",
@@ -515,6 +511,13 @@ fn main() {
         inside = Some(false);
     }
 
+    if matches.opt_present("quiet") {
+        config
+            .borrow_mut()
+            .options
+            .insert("quiet".to_string(), "true".to_string());
+    }
+
     if matches.opt_present("group") {
         let _: u32 = match matches.opt_str("group").unwrap().trim().parse() {
             Ok(x) => x,
@@ -634,7 +637,7 @@ fn main() {
         }
     }
 
-    let stdin_ready = fd_ready(std::io::stdin().as_raw_fd());
+    let stdin_ready = fd_ready(std::io::stdin().as_fd());
     if (stdin_ready && wait_stdin(&matches)) || matches.opt_str("file").is_some() {
         let path = if stdin_ready {
             "-".to_string()
